@@ -338,6 +338,11 @@ def update_throughput(table_name, read_units, write_units):
                     table_name,
                     error.body['message']))
 
+            elif dynamodb_error == 'ResourceInUseException':
+                logger.warning('{0} - ResourceInUseException: {1}'.format(
+                    table_name,
+                    error.body['message']))
+
             else:
                 logger.error(
                     (
